==> banshee-0.9.12.tar.gz: banshee-0.9.12/src/ToggleStates.cs <==
/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
/***************************************************************************
 *  PlayerInterface.cs
 *
 *  Copyright (C) 2005 Novell
 *  Written by Aaron Bockover (aaron@aaronbock.net)
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using System;
using Mono.Unix;
using Banshee.Widgets;

namespace Banshee
{
    public class RepeatNoneToggleState : ToggleState
    {
        public RepeatNoneToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-none.png");
            Label = Catalog.GetString("Repeat None");
        }
    }

    public class RepeatSingleToggleState : ToggleState
    {
        public RepeatSingleToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-single.png");
            Label = Catalog.GetString("Repeat Single");
        }
    }

    public class RepeatAllToggleState : ToggleState
    {
        public RepeatAllToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-all.png");
            Label = Catalog.GetString("Repeat All");
        }
    }
    
    public class ShuffleEnabledToggleState : ToggleState
    {
        public ShuffleEnabledToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-shuffle-enabled.png");
            Label = Catalog.GetString("Shuffle Enabled");
        }
    }
    
    public class ShuffleDisabledToggleState : ToggleState
    {
        public ShuffleDisabledToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-shuffle-disabled.png");
            Label = Catalog.GetString("Shuffle Disabled");
        }
    }
}

==> banshee-0.10.4.tar.gz: banshee-0.10.4/src/ToggleStates.cs <==
/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
/***************************************************************************
 *  PlayerInterface.cs
 *
 *  Copyright (C) 2005 Novell
 *  Written by Aaron Bockover (aaron@aaronbock.net)
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */
 
using System;
using Mono.Unix;
using Banshee.Widgets;

namespace Banshee
{
    public class RepeatNoneToggleState : ToggleState
    {
        public RepeatNoneToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-none.png");
            Label = Catalog.GetString("Repeat None");
        }
    }

    public class RepeatSingleToggleState : ToggleState
    {
        public RepeatSingleToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-single.png");
            Label = Catalog.GetString("Repeat Single");
        }
    }

    public class RepeatAllToggleState : ToggleState
    {
        public RepeatAllToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-repeat-all.png");
            Label = Catalog.GetString("Repeat All");
        }
    }
    
    public class ShuffleEnabledToggleState : ToggleState
    {
        public ShuffleEnabledToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-playlist-shuffle.png");
            Label = Catalog.GetString("Shuffle");
        }
    }
    
    public class ShuffleDisabledToggleState : ToggleState
    {
        public ShuffleDisabledToggleState()
        {
            Icon = Gdk.Pixbuf.LoadFromResource("media-playlist-continuous.png");
            Label = Catalog.GetString("Continuous");
        }
    }
}
